==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_functions/mp3015_001/MP3015_GetDepreciationDefault_001.java <==

package net.datastream.schemas.mp_functions.mp3015_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPRECIATIONCATEGORYID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTDEPTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPRECIATIONCATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="DepreciationDefault" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "equipmentconfigurationid",
    "equipmentdeptype",
    "depreciationcategoryid",
    "fromdate"
})
@XmlRootElement(name = "MP3015_GetDepreciationDefault_001")
public class MP3015_GetDepreciationDefault_001 {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTDEPTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String equipmentdeptype;
    @XmlElement(name = "DEPRECIATIONCATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPRECIATIONCATEGORYID_Type depreciationcategoryid;
    @XmlElement(name = "FROMDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME fromdate;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the equipmentconfigurationid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Sets the value of the equipmentconfigurationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Gets the value of the equipmentdeptype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTDEPTYPE() {
        return equipmentdeptype;
    }

    /**
     * Sets the value of the equipmentdeptype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTDEPTYPE(String value) {
        this.equipmentdeptype = value;
    }

    /**
     * Gets the value of the depreciationcategoryid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPRECIATIONCATEGORYID_Type }
     *     
     */
    public DEPRECIATIONCATEGORYID_Type getDEPRECIATIONCATEGORYID() {
        return depreciationcategoryid;
    }

    /**
     * Sets the value of the depreciationcategoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPRECIATIONCATEGORYID_Type }
     *     
     */
    public void setDEPRECIATIONCATEGORYID(DEPRECIATIONCATEGORYID_Type value) {
        this.depreciationcategoryid = value;
    }

    /**
     * Gets the value of the fromdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getFROMDATE() {
        return fromdate;
    }

    /**
     * Sets the value of the fromdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setFROMDATE(DATETIME value) {
        this.fromdate = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.DEPRECIATION_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_functions/mp3015_001/MP3015_GetDepreciationDefault_001.java <==

package net.datastream.schemas.mp_functions.mp3015_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPRECIATIONCATEGORYID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTCONFIGURATIONID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGURATIONID"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTDEPTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPRECIATIONCATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="DepreciationDefault" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentid",
    "equipmentconfigurationid",
    "equipmentdeptype",
    "depreciationcategoryid",
    "fromdate"
})
@XmlRootElement(name = "MP3015_GetDepreciationDefault_001")
public class MP3015_GetDepreciationDefault_001 {

    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "EQUIPMENTCONFIGURATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTCONFIGURATIONID_Type equipmentconfigurationid;
    @XmlElement(name = "EQUIPMENTDEPTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String equipmentdeptype;
    @XmlElement(name = "DEPRECIATIONCATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPRECIATIONCATEGORYID_Type depreciationcategoryid;
    @XmlElement(name = "FROMDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME fromdate;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentconfigurationid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public EQUIPMENTCONFIGURATIONID_Type getEQUIPMENTCONFIGURATIONID() {
        return equipmentconfigurationid;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigurationid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTCONFIGURATIONID_Type }
     *     
     */
    public void setEQUIPMENTCONFIGURATIONID(EQUIPMENTCONFIGURATIONID_Type value) {
        this.equipmentconfigurationid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentdeptype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTDEPTYPE() {
        return equipmentdeptype;
    }

    /**
     * Définit la valeur de la propriété equipmentdeptype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTDEPTYPE(String value) {
        this.equipmentdeptype = value;
    }

    /**
     * Obtient la valeur de la propriété depreciationcategoryid.
     * 
     * @return
     *     possible object is
     *     {@link DEPRECIATIONCATEGORYID_Type }
     *     
     */
    public DEPRECIATIONCATEGORYID_Type getDEPRECIATIONCATEGORYID() {
        return depreciationcategoryid;
    }

    /**
     * Définit la valeur de la propriété depreciationcategoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPRECIATIONCATEGORYID_Type }
     *     
     */
    public void setDEPRECIATIONCATEGORYID(DEPRECIATIONCATEGORYID_Type value) {
        this.depreciationcategoryid = value;
    }

    /**
     * Obtient la valeur de la propriété fromdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getFROMDATE() {
        return fromdate;
    }

    /**
     * Définit la valeur de la propriété fromdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setFROMDATE(DATETIME value) {
        this.fromdate = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.DEPRECIATION_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
